@@ -1,6 +1,6 @@
 package TimTools;
 
-use 5.006;
+use 5.30;
 use strict;
 use warnings;
 
@@ -10,30 +10,15 @@ TimTools - Some common functions.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
-
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
-
-Perhaps a little code snippet.
-
-    use TimTools;
-
-    my $foo = TimTools->new();
-    ...
-
-=head1 EXPORT
-
-A list of functions that can be exported.  You can delete this section
-if you don't export anything, such as for a purely object-oriented module.
-
-=head1 SUBROUTINES/METHODS
+Nothing to show. Just an umbrella module.
 
 =head1 AUTHOR
 
@@ -45,16 +30,12 @@ Please report any bugs or feature requests to C<bug-timtools at rt.cpan.org>, or
 the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=TimTools>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc TimTools
 
-
 You can also look for information at:
 
 =over 4
@@ -85,7 +66,6 @@ This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
-
 =cut
 
 1; # End of TimTools
